@@ -13,7 +13,7 @@
 ##############################################################################
 """Keas Geocodes.
 
-$Id: geocode.py 92748 2008-11-01 21:36:06Z nadako $
+$Id: geocode.py 102312 2009-07-27 01:32:28Z srichter $
 """
 
 # Interesting Python library for geocoding here:
@@ -25,7 +25,7 @@ from math import asin, sqrt, cos, sin, pi
 from zope.component import adapts, adapter
 from zope.interface import implements, implementer
 from zope.schema.fieldproperty import FieldProperty
-from zope.app.container.btree import BTreeContainer
+from zope.container.btree import BTreeContainer
 import zope.annotation
 
 from keas.googlemap import interfaces, apikey
